@@ -26,6 +26,10 @@ class AzureSynthesizer(BaseSynthesizer):
             speech_config.set_speech_synthesis_output_format(
                 speechsdk.SpeechSynthesisOutputFormat.Raw48Khz16BitMonoPcm
             )
+        if self.sampling_rate == 22050:
+            speech_config.set_speech_synthesis_output_format(
+                speechsdk.SpeechSynthesisOutputFormat.Raw22050Hz16BitMonoPcm
+            )
         if self.sampling_rate == 24000:
             speech_config.set_speech_synthesis_output_format(
                 speechsdk.SpeechSynthesisOutputFormat.Raw24Khz16BitMonoPcm
